/*
 * HelpFrame.java
 *
 * Created on June 29, 2001, 8:50 AM
 *
 * See LICENSE file for license conditions.
 */

package residue;

import java.net.URL;
import javax.swing.JOptionPane;
import java.awt.Dimension;
import java.awt.Toolkit;
import java.awt.Rectangle;
import javax.swing.event.HyperlinkEvent;
import javax.swing.event.HyperlinkListener;
import java.util.Properties;
import java.io.File;
import java.io.InputStream;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.FileOutputStream;
import java.io.OutputStream;

/**
 * This class just wraps a JEditorPane inside a JFrame that
 * hides on exit.  It's primary use is to display text files
 * in a possibly hyperlinked fashion, as the help viewer.
 *
 * @author  chowells
 */
public class HelpFrame extends javax.swing.JFrame
{
	// enums used for persistence.
	private static final String TOP_BOUND_PROPERTY = "help.top";
	private static final String LEFT_BOUND_PROPERTY = "help.left";
	private static final String WIDTH_PROPERTY = "help.width";
	private static final String HEIGHT_PROPERTY = "help.height";
	
	/**
	 * Creates new form HelpFrame, loading the URL given
	 */
    public HelpFrame(URL page) throws java.io.IOException
	{
        initComponents();
		jEditorPane2.setPage(page);
		
		setLinkPopup();
		
		loadLocation();
		storeLocationOnExit();
    } // HelpFrame
	
	/**
	 * Sets the frame to deal with links being clicked on by opening
	 * a dialog box.  The dialog box displays a message informing the
	 * user that links won't work within the help viewer.
	 */
	private void setLinkPopup()
	{
		jEditorPane2.addHyperlinkListener(new HyperlinkListener()
		{
			public void hyperlinkUpdate(HyperlinkEvent e)
			{
				if (e.getEventType() == HyperlinkEvent.EventType.ACTIVATED)
				{
					JOptionPane.showMessageDialog(HelpFrame.this,
						"Unable to follow hyperlinks in help viewer",
						"Warning",
						JOptionPane.ERROR_MESSAGE);
				}
			} // hyperlinkUpdate
		}); // anonymous HyperlinkListener
	} // setLinkPopup
	
	
	/**
	 * adds a shutdownhook which will store the current bounds
	 * of this window when the program is shut down.
	 */
	private void storeLocationOnExit()
	{
		Runtime.getRuntime().addShutdownHook(new Thread(new Runnable ()
		{
			public void run()
			{
				String propname = System.getProperty("user.home") + File.separator + ".gretelrc";
				
				Properties p = new Properties();
				try
				{
					InputStream is = new FileInputStream(propname);
					p.load(is);
					
					is.close();
				}
				catch (IOException e) {}
				
				Rectangle r = getBounds();
				
				p.setProperty(TOP_BOUND_PROPERTY, String.valueOf(r.y));
				p.setProperty(LEFT_BOUND_PROPERTY, String.valueOf(r.x));
				p.setProperty(WIDTH_PROPERTY, String.valueOf(r.width));
				p.setProperty(HEIGHT_PROPERTY, String.valueOf(r.height));
				
				try
				{
					OutputStream os = new FileOutputStream(propname);
					p.store(os, "Gretel configuration file.");
					os.close();
				}
				catch (IOException e) {}
			} // run
		})); // anonymous runnable for shutdown
	} // storeLocationOnExit
	
	
	/**
	 * sets the bounds of this window according to the contents of
	 * the properties file.
	 */
	private void loadLocation()
	{
		Dimension d = Toolkit.getDefaultToolkit().getScreenSize();
		
		int top = (d.height - getHeight()) / 2;
		int left = (d.width - getWidth()) / 2;
		int w = getWidth();
		int h = getHeight();
		
		String propname = System.getProperty("user.home") + File.separator + ".gretelrc";
		
		Properties p = new Properties();
		try
		{
			InputStream is = new FileInputStream(propname);
			p.load(is);
			
			is.close();
		}
		catch (IOException e) {}
		
		try { top = Integer.decode(p.getProperty(TOP_BOUND_PROPERTY)).intValue(); }
		catch (Exception e) {}
		if (top > d.height) top = d.height - 5;
		
		try { left = Integer.decode(p.getProperty(LEFT_BOUND_PROPERTY)).intValue(); }
		catch (Exception e) {}
		if (left > d.width) top = d.width - 5;
		
		try { w = Integer.decode(p.getProperty(WIDTH_PROPERTY)).intValue(); }
		catch (Exception e) {}
		
		try { h = Integer.decode(p.getProperty(HEIGHT_PROPERTY)).intValue(); }
		catch (Exception e) {}
		
		setBounds(left, top, w, h);
	} // loadLocation

	
    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
	private void initComponents()//GEN-BEGIN:initComponents
	{
		jScrollPane1 = new javax.swing.JScrollPane();
		jEditorPane2 = new javax.swing.JEditorPane();
		
		setTitle("Gretel Help");
		addWindowListener(new java.awt.event.WindowAdapter()
		{
			public void windowClosing(java.awt.event.WindowEvent evt)
			{
				exitForm(evt);
			}
		});
		
		jScrollPane1.setPreferredSize(new java.awt.Dimension(600, 440));
		jEditorPane2.setEditable(false);
		jScrollPane1.setViewportView(jEditorPane2);
		
		getContentPane().add(jScrollPane1, java.awt.BorderLayout.CENTER);
		
		pack();
	}//GEN-END:initComponents
	
	/** Exit the Form */
	private void exitForm(java.awt.event.WindowEvent evt) {//GEN-FIRST:event_exitForm
		hide();
	}//GEN-LAST:event_exitForm
	
	// Variables declaration - do not modify//GEN-BEGIN:variables
	private javax.swing.JScrollPane jScrollPane1;
	private javax.swing.JEditorPane jEditorPane2;
	// End of variables declaration//GEN-END:variables

} // class HelpFrame
